@@ -40,7 +40,7 @@ NNS.PDF <- function(variable, degree = 1, target = NULL, bins = NULL , plot = TR
     tgt <- seq(min(target), max(target), d.dx)
   }
   CDF <- NNS.CDF(variable, plot = FALSE, degree = degree)$Function
-  PDF <- pmax(dy.dx(unlist(CDF[,1]), unlist(CDF[,2]), eval.point = tgt, deriv.method = "FD")$First, 0)
+  PDF <- pmax(dy.dx(unlist(CDF[,1]), unlist(CDF[,2]), eval.point = tgt)$First, 0)
   if(plot){
     plot(tgt, PDF, col = 'steelblue', type = 'l', lwd = 3, xlab = "X", ylab = "Density")
   }
